from whitebox.plugins import AppConfig


class WhiteboxPluginTelegrafConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "whitebox_plugin_telegraf"
    verbose_name = "Hardware Monitoring (Telegraf)"
