from whitebox.plugins import Plugin


class WhiteboxPluginTelegraf(Plugin):
    name = "Hardware Monitoring"

    provides_capabilities = ["hardware-monitoring"]


plugin_class = WhiteboxPluginTelegraf
